@@ -17,6 +17,9 @@ SERVICE_VERSIONS = {
     "aai": [
         "2018-05-22"
     ],
+    "acp": [
+        "2022-01-05"
+    ],
     "advisor": [
         "2020-07-21"
     ],
@@ -146,6 +149,9 @@ SERVICE_VERSIONS = {
         "2020-11-12",
         "2019-07-18"
     ],
+    "ciam": [
+        "2022-03-31"
+    ],
     "cii": [
         "2021-04-08",
         "2020-12-10"
@@ -377,6 +383,9 @@ SERVICE_VERSIONS = {
         "2020-10-14",
         "2019-09-29"
     ],
+    "mmps": [
+        "2020-07-10"
+    ],
     "mna": [
         "2021-01-19"
     ],
@@ -516,6 +525,9 @@ SERVICE_VERSIONS = {
     "tcb": [
         "2018-06-08"
     ],
+    "tcbr": [
+        "2022-02-17"
+    ],
     "tcex": [
         "2020-07-27"
     ],
@@ -570,6 +582,7 @@ SERVICE_VERSIONS = {
         "2019-05-29"
     ],
     "tione": [
+        "2021-11-11",
         "2019-10-22"
     ],
     "tiw": [
@@ -588,6 +601,9 @@ SERVICE_VERSIONS = {
     "tmt": [
         "2018-03-21"
     ],
+    "trp": [
+        "2021-05-15"
+    ],
     "trtc": [
         "2019-07-22"
     ],
